@@ -1,6 +1,6 @@
 package DBIx::Class::Helper::Schema::LintContents;
 {
-  $DBIx::Class::Helper::Schema::LintContents::VERSION = '2.016002';
+  $DBIx::Class::Helper::Schema::LintContents::VERSION = '2.016003';
 }
 
 use strict;
@@ -45,7 +45,7 @@ sub dup_check_source_auto {
    my %uc = $self->source($source)->unique_constraints;
    return {
       map {
-         $_ => $self->dup_check_source($source, $uc{$_})
+         $_ => scalar $self->dup_check_source($source, $uc{$_})
       } keys %uc
    }
 }
@@ -74,7 +74,7 @@ sub fk_check_source_auto {
 
    return {
       map {
-         $_ => $self->fk_check_source(
+         $_ => scalar $self->fk_check_source(
             $from_moniker,
             $from_source->related_source($_),
             $self->_fk_cond_fixer($rels{$_}->{cond})
@@ -118,7 +118,7 @@ DBIx::Class::Helper::Schema::LintContents - Check the data in your database matc
 
 =head1 VERSION
 
-version 2.016002
+version 2.016003
 
 =head1 SYNOPSIS
 
